@@ -48,9 +48,7 @@ genClientData <- function(col, row, visible, height, width) {
     txt <- paste0(txt, "<x:Visible/>")
   }
 
-  txt <- paste0(txt, "</x:ClientData>")
-
-  return(txt)
+  paste0(txt, "</x:ClientData>")
 }
 
 # # TODO this should be merged with the one above for type Note
@@ -96,7 +94,7 @@ genClientDataFC <- function(left, top, right, bottom, link, range, type, checked
   # - BottomRow
   # - BottomOffset
 
-  txt <- sprintf(
+  sprintf(
     '<x:ClientData ObjectType="%s">
     <x:MoveWithCells/><x:SizeWithCells/>
     <x:Anchor>%s, 0, %s, 0, %s, 0, %s, 0</x:Anchor>
@@ -118,8 +116,6 @@ genClientDataFC <- function(left, top, right, bottom, link, range, type, checked
     as_binary(checked),
     drop
   )
-
-  return(txt)
 }
 
 # This is just a list to remember possible combinations
@@ -248,8 +244,9 @@ genBaseStyleSheet <- function(dxfs = NULL, tableStyles = NULL, extLst = NULL) {
   )
 }
 
-genBasePic <- function(imageNo, next_id) {
-  sprintf('<xdr:pic>
+genBasePic <- function(imageNo, next_id, address_id) {
+
+  pic <- sprintf('<xdr:pic>
       <xdr:nvPicPr>
         <xdr:cNvPr id="%s" name="Picture %s"/>
         <xdr:cNvPicPr>
@@ -257,8 +254,7 @@ genBasePic <- function(imageNo, next_id) {
         </xdr:cNvPicPr>
       </xdr:nvPicPr>
       <xdr:blipFill>
-        <a:blip xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" r:embed="%s">
-        </a:blip>
+        <a:blip r:embed="%s"></a:blip>
         <a:stretch>
           <a:fillRect/>
         </a:stretch>
@@ -269,6 +265,13 @@ genBasePic <- function(imageNo, next_id) {
         </a:prstGeom>
       </xdr:spPr>
     </xdr:pic>', imageNo, imageNo, next_id)
+
+  if (nchar(address_id)) {
+    hlinkClick <- sprintf("<a:hlinkClick r:id=\"%s\"/>", address_id)
+    pic <- xml_add_child(pic, hlinkClick, level = c("xdr:nvPicPr", "xdr:cNvPr"))
+  }
+
+  pic
 }
 
 # TODO: make genBaseTheme() a more flexible function that allows further
@@ -492,7 +495,7 @@ gen_databar_extlst <- function(guid, sqref, posColor, negColor, values, border,
                       </x14:dataBar></x14:cfRule><xm:sqref>%s</xm:sqref></x14:conditionalFormatting>', xml, values[[1]], values[[2]], posColor, negColor, negColor, sqref)
   }
 
-  return(xml)
+  xml
 }
 
 genSlicerCachesExtLst <- function(i) {
@@ -1082,12 +1085,10 @@ drawings <- function(drawings, drawing_id) {
     )
   )
 
-  return(
-    xml_append_child1(
-      node    = read_xml(drawings),
-      child   = read_xml(drawing),
-      pointer = FALSE)
-  )
+  xml_append_child1(
+    node    = read_xml(drawings),
+    child   = read_xml(drawing),
+    pointer = FALSE)
 }
 
 chart1_rels_xml <- function(x) {
@@ -1109,7 +1110,7 @@ drawings_rels <- function(drawings, x) {
 
   rel_len <- length(xml_node(drawings, "Relationship"))
 
-  drawings <- c(
+  c(
     drawings,
     sprintf(
       "<Relationship Id=\"rId%s\" Type=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart\" Target=\"../charts/chart%s.xml\"/>",
@@ -1117,8 +1118,6 @@ drawings_rels <- function(drawings, x) {
       x
     )
   )
-
-  return(drawings)
 }
 
 formCntrlDrawing <- function(type, len) {
