@@ -34,56 +34,30 @@ dims_to_dataframe <- function(dims, fill = FALSE, empty_rm = FALSE) {
   # condition 2) either "A1:B5" or separator, but unequal size or "A1:A2,A4:A6,B1:B5"
   if (has_dim_sep && get_dims(dims, check = TRUE)) {
 
-    full_rows <- get_dims(dims, rows = TRUE)
-    full_cols <- sort(get_dims(dims, cols = TRUE))
+    ldims     <- get_dims(dims)
+    full_rows <- ldims$rows[[1]]
+    full_cols <- ldims$cols
 
-    rows_out  <- unlist(full_rows)
-    rows_out  <- seq.int(rows_out[1], rows_out[2])
-    cols_out  <- int2col(full_cols)
+    rows_out  <- seq.int(full_rows[1], full_rows[2])
+    cols_out  <- full_cols
     full_cols <- full_cols - min(full_cols) # is always a zero offset
 
   } else {
+    ll <- dims_to_row_col_fill(dims, fill)
 
-    for (dim in dims) {
-
-      if (!grepl(":", dim)) {
-        dim <- paste0(dim, ":", dim)
-      }
-
-      if (length(dims) > 1)
-        filled <- c(filled, needed_cells(dim))
-
-      if (identical(dim, "Inf:-Inf")) {
-        # This should probably be fixed elsewhere?
-        stop("dims are inf:-inf")
-      } else {
-        dimensions <- strsplit(dim, ":")[[1]]
-
-        rows <- as.numeric(gsub("[[:upper:]]", "", dimensions))
-        if (all(is.na(rows))) rows <- c(1, 1048576)
-        rows <- seq.int(rows[1], rows[2])
-
-        rows_out <- unique(c(rows_out, rows))
-
-        # TODO seq.wb_columns?  make a wb_cols vector?
-        cols <- gsub("[[:digit:]]", "", dimensions)
-        cols <- int2col(seq.int(col2int(cols[1]), col2int(cols[2])))
-
-        cols_out <- unique(c(cols_out, cols))
-      }
-    }
+    filled   <- ll$fill
+    cols_out <- ll$cols
+    rows_out <- ll$rows
   }
 
   if (has_dim_sep) {
     if (empty_rm) {
-      cols_out  <- int2col(sort(col2int(cols_out)))
-      rows_out  <- sort(rows_out)
       # with empty_rm the dataframe will contain only needed columns
       if (!is.null(full_cols)) full_cols <- seq_along(cols_out) - 1L
     } else {
       # somehow we have to make sure that all columns are covered
-      col_ints <- range(col2int(cols_out))
-      cols_out <- int2col(seq.int(from = col_ints[1], to = col_ints[2]))
+      col_ints <- range(cols_out)
+      cols_out <- seq.int(from = col_ints[1], to = col_ints[2])
 
       row_ints <- range(rows_out)
       rows_out <- seq.int(from = row_ints[1], to = row_ints[2])
@@ -92,7 +66,7 @@ dims_to_dataframe <- function(dims, fill = FALSE, empty_rm = FALSE) {
 
   dims_to_df(
     rows   = rows_out,
-    cols   = cols_out,
+    cols   = int2col(cols_out),
     filled = filled,
     fill   = fill,
     fcols  = full_cols
