@@ -48,7 +48,7 @@ test_that("Maintaining Named Regions on Load", {
 
   # nonsense
   # df1 is a single value and this single value is now used as rowName
-  expect_warning(df1 <- read_xlsx(wb, named_region = "region1", row_names = TRUE))
+  df1 <- read_xlsx(wb, named_region = "region1", row_names = TRUE)
   expect_s3_class(df1, "data.frame")
   expect_equal(nrow(df1), 0)
   expect_equal(ncol(df1), 0)
@@ -524,3 +524,13 @@ test_that("local_sheet works", {
   expect_equal(exp, got)
 
 })
+
+test_that("named region checks work", {
+  wb <- wb_workbook()$add_worksheet()
+
+  expect_error(wb$add_named_region(dims = "A1", name = 1), "letter or an underscore")
+  expect_error(wb$add_named_region(dims = "B1", name = "1"), "letter or an underscore")
+  expect_silent(wb$add_named_region(dims = "C1", name = stringi::stri_unescape_unicode("\\u00e4")))
+  expect_error(wb$add_named_region(dims = "D1", name = "a b"), "letter or an underscore")
+  expect_error(wb$add_named_region(dims = "D1", name = "A1"), "cell reference")
+})
