@@ -726,18 +726,43 @@ test_that("wb_dims(from_dims) positioning works", {
 
 test_that("dims are quick", {
 
+  # full range
   ddims <- dims_to_dataframe(
     "A1:D5000",
     fill = TRUE
   )
-
   edims <- dims_to_dataframe(
     "A1:A5000,B1:B5000,C1:C5000,D1:D5000",
     fill = TRUE
   )
-
   expect_equal(ddims, edims)
 
+  # with blank in between
+  ddims <- dims_to_dataframe(
+    "A1:B5000,D1:E5000",
+    fill = TRUE
+  )
+  edims <- dims_to_dataframe(
+    "A1:A5000,B1:B5000,D1:D5000,E1:E5000",
+    fill = TRUE
+  )
+  expect_equal(ddims, edims)
+
+  # with blank in between and cleaned up
+  ddims <- dims_to_dataframe(
+    "A1:B5000,D1:E5000",
+    fill = TRUE, empty_rm = TRUE
+  )
+  edims <- dims_to_dataframe(
+    "A1:A5000,B1:B5000,D1:D5000,E1:E5000",
+    fill = TRUE, empty_rm = TRUE
+  )
+  expect_equal(ddims, edims)
+
+  expect_silent(dims_to_dataframe("A:C"))
+  expect_silent(dims_to_dataframe("3:3"))
+  expect_error(dims_to_dataframe("A:3"))
+
 })
 
 test_that("wb_dims does not try to validate column names", {
